==> autoprefixer-1.1.20140521.tgz: package/data/browsers.js <==
(function() {
  module.exports = {
    android: {
      prefix: "-webkit-",
      minor: true,
      versions: [4.4, 4.3, 4.2, 4.1, 4, 3, 2.3, 2.2, 2.1],
      popularity: [0.337062, 0.858555, 0.858555, 2.18772, 0.909432, 0.00635967, 1.13202, 0.0699563, 0.0254387]
    },
    bb: {
      prefix: "-webkit-",
      minor: true,
      versions: [10, 7],
      popularity: [0, 0.113215]
    },
    chrome: {
      prefix: "-webkit-",
      future: [38, 37, 36],
      versions: [35, 34, 33, 32, 31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4],
      popularity: [0.134964, 19.4573, 11.5844, 0.71231, 0.809784, 0.239936, 0.41239, 0.172454, 0.457378, 0.172454, 0.082478, 0.052486, 0.067482, 0.11247, 0.48737, 0.03749, 0.022494, 0.067482, 0.022494, 0.029992, 0.052486, 0.03749, 0.044988, 0.052486, 0.11247, 0.029992, 0.014996, 0.022494, 0.014996, 0.022494, 0.022494, 0.022494]
    },
    ff: {
      prefix: "-moz-",
      future: [32, 31, 30],
      versions: [29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3.6, 3.5, 3, 2],
      popularity: [0.48737, 11.382, 0.63733, 0.269928, 0.134964, 0.232438, 0.097474, 0.104972, 0.22494, 0.089976, 0.07498, 0.059984, 0.104972, 0.142462, 0.082478, 0.059984, 0.059984, 0.142462, 0.059984, 0.067482, 0.03749, 0.052486, 0.029992, 0.03749, 0.029992, 0.044988, 0.179952, 0.029992, 0.07498, 0.007498]
    },
    ie: {
      prefix: "-ms-",
      versions: [11, 10, 9, 8, 7, 6, 5.5],
      popularity: [7.0483, 3.02851, 2.78654, 4.76912, 0.163914, 0.288801, 0.009298]
    },
    ios: {
      prefix: "-webkit-",
      versions: [7, 6.1, 6, 5.1, 5, 4.3, 4.2, 4.1, 4, 3.2],
      popularity: [4.58455, 0.3607695, 0.3607695, 0.113781, 0.113781, 0.0111006, 0.0111006, 0.0055503, 0.0055503, 0]
    },
    opera: {
      prefix: "-o-",
      future: [22, 21],
      versions: [20, 19, 18, 17, 16, 15, 12.1, 12, 11.6, 11.5, 11.1, 11, 10.6, 10.5, 10.1, 10, 9.6, 9.5],
      popularity: [0.464876, 0.03749, 0.029992, 0.014996, 0.007498, 0.007498, 0.367402, 0.029992, 0.014996, 0.007498, 0.008219, 0.014996, 0.014996, 0.008392, 0.003749, 0.003749, 0.003749, 0.003749]
    },
    safari: {
      prefix: "-webkit-",
      versions: [7, 6.1, 6, 5.1, 5, 4, 3.2, 3.1],
      popularity: [1.57458, 0.67482, 0.41239, 0.794788, 0.232438, 0.11247, 0.008692, 0]
    }
  };

}).call(this);

==> autoprefixer-1.1.20140523.tgz: package/data/browsers.js <==
(function() {
  module.exports = {
    android: {
      prefix: "-webkit-",
      minor: true,
      versions: [4.4, 4.3, 4.2, 4.1, 4, 3, 2.3, 2.2, 2.1],
      popularity: [0.337062, 0.858555, 0.858555, 2.18772, 0.909432, 0.00635967, 1.13202, 0.0699563, 0.0254387]
    },
    bb: {
      prefix: "-webkit-",
      minor: true,
      versions: [10, 7],
      popularity: [0, 0.113215]
    },
    chrome: {
      prefix: "-webkit-",
      future: [38, 37, 36],
      versions: [35, 34, 33, 32, 31, 30, 29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4],
      popularity: [0.134964, 19.4573, 11.5844, 0.71231, 0.809784, 0.239936, 0.41239, 0.172454, 0.457378, 0.172454, 0.082478, 0.052486, 0.067482, 0.11247, 0.48737, 0.03749, 0.022494, 0.067482, 0.022494, 0.029992, 0.052486, 0.03749, 0.044988, 0.052486, 0.11247, 0.029992, 0.014996, 0.022494, 0.014996, 0.022494, 0.022494, 0.022494]
    },
    ff: {
      prefix: "-moz-",
      future: [32, 31, 30],
      versions: [29, 28, 27, 26, 25, 24, 23, 22, 21, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3.6, 3.5, 3, 2],
      popularity: [0.48737, 11.382, 0.63733, 0.269928, 0.134964, 0.232438, 0.097474, 0.104972, 0.22494, 0.089976, 0.07498, 0.059984, 0.104972, 0.142462, 0.082478, 0.059984, 0.059984, 0.142462, 0.059984, 0.067482, 0.03749, 0.052486, 0.029992, 0.03749, 0.029992, 0.044988, 0.179952, 0.029992, 0.07498, 0.007498]
    },
    ie: {
      prefix: "-ms-",
      versions: [11, 10, 9, 8, 7, 6, 5.5],
      popularity: [7.0483, 3.02851, 2.78654, 4.76912, 0.163914, 0.288801, 0.009298]
    },
    ios: {
      prefix: "-webkit-",
      versions: [7, 6.1, 6, 5.1, 5, 4.3, 4.2, 4.1, 4, 3.2],
      popularity: [4.58455, 0.3607695, 0.3607695, 0.113781, 0.113781, 0.0111006, 0.0111006, 0.0055503, 0.0055503, 0]
    },
    opera: {
      prefix: "-o-",
      future: [23, 22],
      versions: [21, 20, 19, 18, 17, 16, 15, 12.1, 12, 11.6, 11.5, 11.1, 11, 10.6, 10.5, 10.1, 10, 9.6, 9.5],
      popularity: [0.014996, 0.464876, 0.03749, 0.029992, 0.014996, 0.007498, 0.007498, 0.367402, 0.029992, 0.014996, 0.007498, 0.008219, 0.014996, 0.014996, 0.008392, 0.003749, 0.003749, 0.003749, 0.003749]
    },
    safari: {
      prefix: "-webkit-",
      versions: [7, 6.1, 6, 5.1, 5, 4, 3.2, 3.1],
      popularity: [1.57458, 0.67482, 0.41239, 0.794788, 0.232438, 0.11247, 0.008692, 0]
    }
  };

}).call(this);
